@@ -4,9 +4,9 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include <barcode.h>
-#include <boardingpass.h>
-#include <location.h>
+#include "barcode.h"
+#include "boardingpass.h"
+#include "location.h"
 
 #include <QLocale>
 #include <QTest>
@@ -29,30 +29,30 @@ private Q_SLOTS:
         QVERIFY(pass);
 
         QCOMPARE(pass->type(), KPkPass::Pass::BoardingPass);
-        QCOMPARE(pass->serialNumber(), QLatin1String("1234"));
-        QCOMPARE(pass->description(), QLatin1String("description"));
-        QCOMPARE(pass->organizationName(), QLatin1String("KDE"));
+        QCOMPARE(pass->serialNumber(), QLatin1StringView("1234"));
+        QCOMPARE(pass->description(), QLatin1StringView("description"));
+        QCOMPARE(pass->organizationName(), QLatin1StringView("KDE"));
 
-        QCOMPARE(pass->logoText(), QLatin1String("Boarding Pass"));
+        QCOMPARE(pass->logoText(), QLatin1StringView("Boarding Pass"));
         QCOMPARE(pass->backgroundColor(), QColor(61, 174, 233));
         QCOMPARE(pass->relevantDate(), QDateTime(QDate(2017, 9, 17), QTime(0, 4, 0), QTimeZone::UTC));
         QCOMPARE(pass->expirationDate(), QDateTime(QDate(2017, 9, 18), QTime(0, 0, 36), QTimeZone::UTC));
         QCOMPARE(pass->isVoided(), false);
-        QCOMPARE(pass->groupingIdentifier(), QLatin1String(""));
+        QCOMPARE(pass->groupingIdentifier(), QLatin1StringView(""));
 
         QCOMPARE(pass->fields().size(), 12);
         auto headers = pass->headerFields();
         QCOMPARE(headers.size(), 2);
         auto field = headers.at(0);
-        QCOMPARE(field.label(), QLatin1String("Sitzplatz"));
-        QCOMPARE(field.value().toString(), QLatin1String("10E"));
-        QCOMPARE(field.valueDisplayString(), QLatin1String("10E"));
-        QCOMPARE(field.key(), QLatin1String("seat"));
+        QCOMPARE(field.label(), QLatin1StringView("Sitzplatz"));
+        QCOMPARE(field.value().toString(), QLatin1StringView("10E"));
+        QCOMPARE(field.valueDisplayString(), QLatin1StringView("10E"));
+        QCOMPARE(field.key(), QLatin1StringView("seat"));
         QCOMPARE(field.changeMessage(), QStringLiteral("Sitzplatznummer geändert in 10E"));
 
         field = pass->field(QStringLiteral("boarding"));
-        QCOMPARE(field.key(), QLatin1String("boarding"));
-        QCOMPARE(field.value().toString(), QLatin1String("20:25"));
+        QCOMPARE(field.key(), QLatin1StringView("boarding"));
+        QCOMPARE(field.value().toString(), QLatin1StringView("20:25"));
         QCOMPARE(field.textAlignment(), Qt::AlignLeft);
 
         auto boardingPass = dynamic_cast<KPkPass::BoardingPass *>(pass.get());
@@ -65,7 +65,7 @@ private Q_SLOTS:
         QCOMPARE(bc.format(), KPkPass::Barcode::QR);
         QVERIFY(!bc.message().isEmpty());
         QVERIFY(bc.alternativeText().isEmpty());
-        QCOMPARE(bc.messageEncoding(), QLatin1String("iso-8859-1"));
+        QCOMPARE(bc.messageEncoding(), QLatin1StringView("iso-8859-1"));
 
         const auto locs = pass->locations();
         QCOMPARE(locs.size(), 1);
@@ -73,7 +73,7 @@ private Q_SLOTS:
         QVERIFY(std::isnan(loc.altitude()));
         QCOMPARE((int)loc.latitude(), 47);
         QCOMPARE((int)loc.longitude(), 8);
-        QCOMPARE(loc.relevantText(), QLatin1String("LX962 Boarding 20:25"));
+        QCOMPARE(loc.relevantText(), QLatin1StringView("LX962 Boarding 20:25"));
         QCOMPARE(pass->maximumDistance(), 500);
 
         QCOMPARE(pass->hasIcon(), false);
